@@ -167,7 +167,7 @@ Stop all Docker containers for the current QuickScale project.
 This will stop both the web and database services.
         """)
         
-    subparsers.add_parser("destroy", 
+    destroy_parser = subparsers.add_parser("destroy", 
         help="Destroy the current project in local development mode",
         description="""
 WARNING: This command will permanently delete:
@@ -175,8 +175,14 @@ WARNING: This command will permanently delete:
 - All Docker containers and volumes
 - All database data
 
+By default, Docker images are NOT deleted (for faster rebuilds). To also delete images, pass --delete-images.
+
 This action cannot be undone. Use 'down' instead if you just want to stop services.
         """)
+    destroy_parser.add_argument(
+        "--delete-images",
+        action="store_true",
+        help="Also delete Docker images (slower rebuild, default: keep images)")
 
 
 def setup_utility_parsers(subparsers: argparse._SubParsersAction) -> None:
@@ -274,6 +280,7 @@ Examples:
   quickscale generate-service sentiment_analyzer --type text_processing --credit-cost 2.5
   quickscale generate-service image_classifier --type image_processing --description "Advanced image classification service"
   quickscale generate-service my_service --credit-cost 0.5 --description "Low-cost utility service"
+  quickscale generate-service free_utility --free --description "Free utility service"
   quickscale generate-service test_service --skip-db-config  (generate files only, skip database configuration)
 
 Note: If your project isn't running (quickscale up), database configuration will be skipped automatically
@@ -298,6 +305,10 @@ with instructions on how to configure it later. This is normal behavior.
         type=float,
         default=1.0,
         help="Credit cost for using this service (default: 1.0)")
+    generate_parser.add_argument(
+        "--free",
+        action="store_true",
+        help="Generate a free service with 0.0 credit cost (overrides --credit-cost)")
     generate_parser.add_argument(
         "--description",
         help="Description of the service (if not provided, will be auto-generated)")
@@ -370,6 +381,75 @@ For Django management commands help, use:
         description="Display the installed version of QuickScale CLI.")
 
 
+def setup_sync_back_parser(subparsers: argparse._SubParsersAction) -> None:
+    """Set up sync-back command parser."""
+    sync_back_parser = subparsers.add_parser("sync-back",
+        help="Sync changes from generated project back to QuickScale templates",
+        description="""
+Sync-Back: Reverse Development Workflow
+
+This command allows you to sync changes from a generated QuickScale project back 
+to the QuickScale template files. This enables a reverse development workflow where 
+you can modify templates in a generated project and sync those changes back.
+
+REQUIREMENTS:
+- QuickScale must be installed in development mode (Git clone + pip install -e .)
+- If installed via 'pip install quickscale', this command will show instructions
+
+WORKFLOW:
+1. Generate project: quickscale init my-project
+2. Develop changes: Edit files in generated project  
+3. Navigate to project: cd my-project
+4. Preview changes: quickscale sync-back --preview
+5. Apply changes: quickscale sync-back --apply
+6. Interactive mode: quickscale sync-back --interactive
+
+Alternative: Use from outside project directory:
+3. Preview changes: quickscale sync-back ./my-project --preview
+4. Apply changes: quickscale sync-back ./my-project --apply
+5. Interactive mode: quickscale sync-back ./my-project --interactive
+
+FILE CATEGORIZATION:
+- Safe Files (Direct Copy): Templates, static files, documentation
+- Careful Files (Variable Restoration): Settings files with template variables restored
+- Never Sync (Auto-Skip): Database files, migrations, logs, cache files
+        """,
+        epilog="""
+Examples:
+  quickscale sync-back --preview                 Show what would be synced (from current directory)
+  quickscale sync-back --apply                   Apply sync-back changes (from current directory)
+  quickscale sync-back --interactive             Interactively review and apply changes (from current directory)
+  quickscale sync-back ./my-project --preview    Show what would be synced (specify project path)
+  quickscale sync-back ./my-project --apply      Apply changes (specify project path)
+  quickscale sync-back ./my-project --interactive Interactive mode (specify project path)
+
+Note: Always preview changes before applying them or use interactive mode for fine-grained control.
+        """,
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        usage="quickscale sync-back [project_path] [--preview | --apply | --interactive]")
+    
+    sync_back_parser.add_argument(
+        "project_path",
+        nargs="?",
+        default=".",
+        help="Path to the generated QuickScale project (defaults to current directory)")
+    
+    # Create mutually exclusive group for preview/apply/interactive
+    action_group = sync_back_parser.add_mutually_exclusive_group(required=True)
+    action_group.add_argument(
+        "--preview",
+        action="store_true",
+        help="Show preview of changes without applying them")
+    action_group.add_argument(
+        "--apply",
+        action="store_true",
+        help="Apply changes from project to templates")
+    action_group.add_argument(
+        "--interactive",
+        action="store_true",
+        help="Interactively review and apply changes file by file")
+
+
 def handle_init_command(args: argparse.Namespace) -> int:
     """Handle initialization command."""
     from quickscale.utils.message_manager import MessageManager
@@ -457,6 +537,7 @@ def main() -> int:
     setup_logs_parser(subparsers)
     setup_manage_parser(subparsers)
     setup_service_generator_parsers(subparsers)
+    setup_sync_back_parser(subparsers)
     setup_help_and_version_parsers(subparsers)
     
     # Parse arguments
