@@ -14,18 +14,27 @@ class ServiceGeneratorCommand(Command):
     """Command to generate service templates for AI engineers."""
     
     def execute(self, service_name: str, service_type: str = "basic", output_dir: Optional[str] = None, 
-                credit_cost: float = 1.0, description: Optional[str] = None, skip_db_config: bool = False) -> Dict[str, Any]:
+                credit_cost: float = 1.0, description: Optional[str] = None, skip_db_config: bool = False, 
+                free: bool = False) -> Dict[str, Any]:
         """Generate a new service template."""
         self.logger.info(f"Generating service template: {service_name}")
         
         # Validate service name
         if not self._validate_service_name(service_name):
-            raise ValueError(f"Invalid service name: {service_name}")
+            return {
+                "success": False,
+                "error": f"Invalid service name: {service_name}",
+                "message": "Service name must be a valid Python identifier using snake_case (e.g., text_analyzer, sentiment_processor)"
+            }
         
         # Generate description if not provided
         if not description:
             description = f"AI service: {service_name.replace('_', ' ').title()}"
         
+        # Handle free flag (overrides credit_cost)
+        if free:
+            credit_cost = 0.0
+        
         # Determine output directory
         if output_dir:
             target_dir = Path(output_dir)
@@ -58,21 +67,25 @@ class ServiceGeneratorCommand(Command):
         # Render template
         rendered_content = render_template(template_content, variables)
         
-        # Write service file
-        with open(service_file_path, 'w', encoding='utf-8') as f:
-            f.write(rendered_content)
-        
-        MessageManager.success(f"Service template generated: {service_file_path}")
-        
-        # Generate usage example
-        example_file_path = target_dir / f"{service_name}_example.py"
-        example_content = self._get_usage_example_template()
-        rendered_example = render_template(example_content, variables)
-        
-        with open(example_file_path, 'w', encoding='utf-8') as f:
-            f.write(rendered_example)
-        
-        MessageManager.success(f"Usage example generated: {example_file_path}")
+        try:
+            # Write service file
+            with open(service_file_path, 'w', encoding='utf-8') as f:
+                f.write(rendered_content)
+            
+            MessageManager.success(f"Service template generated: {service_file_path}")
+            
+            # Generate usage example
+            example_file_path = target_dir / f"{service_name}_example.py"
+            example_content = self._get_usage_example_template()
+            rendered_example = render_template(example_content, variables)
+            
+            with open(example_file_path, 'w', encoding='utf-8') as f:
+                f.write(rendered_example)
+            
+            MessageManager.success(f"Usage example generated: {example_file_path}")
+            
+        except (PermissionError, OSError) as e:
+            return {"success": False, "error": str(e)}
         
         result = {
             "success": True,
@@ -89,34 +102,40 @@ class ServiceGeneratorCommand(Command):
                 db_config_result = self._configure_service_in_database(service_name, description, credit_cost)
                 result["database_configured"] = db_config_result["success"]
                 if db_config_result["success"]:
-                    MessageManager.success(f"Service '{service_name}' configured in database with {credit_cost} credit cost")
+                    if credit_cost == 0.0:
+                        MessageManager.success(f"Free service '{service_name}' configured in database (0.0 credit cost)")
+                    else:
+                        MessageManager.success(f"Service '{service_name}' configured in database with {credit_cost} credit cost")
                 else:
                     reason = db_config_result.get('reason', 'Unknown reason')
                     MessageManager.warning(f"Database configuration skipped: {reason}")
                     
                     # Provide helpful guidance based on the specific failure reason
+                    cost_flag = "--free" if credit_cost == 0.0 else f"--credit-cost {credit_cost}"
                     if "Docker services are not running" in reason:
                         MessageManager.info("To configure the service in the database:")
                         MessageManager.info(f"  1. Start your project: quickscale up")
-                        MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" --credit-cost {credit_cost}")
+                        MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" {cost_flag}")
                     elif "Cannot check Docker services" in reason:
                         MessageManager.info("To configure the service in the database:")
                         MessageManager.info(f"  1. Ensure Docker is running and project is started: quickscale up")
-                        MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" --credit-cost {credit_cost}")
+                        MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" {cost_flag}")
                     else:
-                        MessageManager.info(f"You can configure it manually with: quickscale manage configure_service {service_name} --description \"{description}\" --credit-cost {credit_cost}")
+                        MessageManager.info(f"You can configure it manually with: quickscale manage configure_service {service_name} --description \"{description}\" {cost_flag}")
                     
                     result["database_config_warning"] = reason
             except Exception as e:
                 MessageManager.warning(f"Could not configure service in database: {str(e)}")
+                cost_flag = "--free" if credit_cost == 0.0 else f"--credit-cost {credit_cost}"
                 MessageManager.info("To configure the service in the database:")
                 MessageManager.info(f"  1. Start your project: quickscale up")
-                MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" --credit-cost {credit_cost}")
+                MessageManager.info(f"  2. Configure service: quickscale manage configure_service {service_name} --description \"{description}\" {cost_flag}")
                 result["database_configured"] = False
                 result["database_config_error"] = str(e)
         else:
+            cost_flag = "--free" if credit_cost == 0.0 else f"--credit-cost {credit_cost}"
             MessageManager.info(f"Database configuration skipped. Configure manually with:")
-            MessageManager.info(f"  quickscale manage configure_service {service_name} --description \"{description}\" --credit-cost {credit_cost}")
+            MessageManager.info(f"  quickscale manage configure_service {service_name} --description \"{description}\" {cost_flag}")
             result["database_configured"] = False
             result["database_config_skipped"] = True
         
@@ -124,6 +143,8 @@ class ServiceGeneratorCommand(Command):
     
     def _validate_service_name(self, service_name: str) -> bool:
         """Validate service name follows Python naming conventions."""
+        import keyword
+        
         if not service_name:
             return False
         
@@ -131,6 +152,14 @@ class ServiceGeneratorCommand(Command):
         if not service_name.isidentifier():
             return False
         
+        # Should not be a Python keyword
+        if keyword.iskeyword(service_name):
+            return False
+        
+        # Should not start with underscore (reserved for special methods/private)
+        if service_name.startswith('_'):
+            return False
+        
         # Should not start with uppercase (by convention)
         if service_name[0].isupper():
             return False
@@ -174,9 +203,14 @@ class ServiceGeneratorCommand(Command):
             cmd = [
                 'quickscale', 'manage', 'configure_service', service_name,
                 '--description', description,
-                '--credit-cost', str(credit_cost)
             ]
             
+            # Add appropriate cost argument
+            if credit_cost == 0.0:
+                cmd.append('--free')
+            else:
+                cmd.extend(['--credit-cost', str(credit_cost)])
+            
             result = subprocess.run(cmd, capture_output=True, text=True, timeout=DOCKER_OPERATIONS_TIMEOUT)
             
             if result.returncode == 0:
@@ -458,7 +492,7 @@ class ValidateServiceCommand(Command):
         if show_tips:
             ServiceDevelopmentHelper.display_development_tips()
             MessageManager.info("")
-        
+
         service_file_path: Optional[Path] = None
 
         if not name_or_path:
@@ -476,13 +510,24 @@ class ValidateServiceCommand(Command):
             service_file_path = Path.cwd() / "services" / f"{name_or_path}_service.py"
 
         if not service_file_path or not service_file_path.exists():
-            raise CommandError(f"Service file not found at: {service_file_path}\n\nSuggestion: Ensure the service name is correct or provide the full path to the service file.")
-
-        validate_service_file(str(service_file_path))
-        
-        return {"validation_completed": True}
-
+            return {
+                "valid": False,
+                "validation_completed": True,
+                "error": f"Service file not found at: {service_file_path}"
+            }
 
+        try:
+            validate_service_file(str(service_file_path))
+            return {
+                "valid": True,
+                "validation_completed": True
+            }
+        except CommandError:
+            return {
+                "valid": False,
+                "validation_completed": True,
+                "error": "Service validation failed due to structural issues"
+            }
 class ServiceExamplesCommand(Command):
     """Command to show available service examples."""
     
@@ -512,4 +557,9 @@ class ServiceExamplesCommand(Command):
             return {"examples": filtered_examples, "count": len(filtered_examples)}
         else:
             show_service_examples()
-            return {"examples_displayed": True} 
\ No newline at end of file
+            examples = ServiceDevelopmentHelper.get_service_examples()
+            return {
+                "examples_displayed": True,
+                "examples": examples,
+                "count": len(examples)
+            } 
\ No newline at end of file
