@@ -5,32 +5,20 @@ This module centralizes all timeout configurations used throughout the QuickScal
 project to improve maintainability and consistency.
 """
 
-# Docker service startup timeout
-DOCKER_SERVICE_STARTUP_TIMEOUT = 60  # > DOCKER_CONTAINER_START_TIMEOUT
-
-# Docker ps command timeout for checking service status 
-DOCKER_PS_CHECK_TIMEOUT = 20  # < DOCKER_OPERATIONS_TIMEOUT
-
-# Docker container start timeout
-DOCKER_CONTAINER_START_TIMEOUT = 30  # > DOCKER_OPERATIONS_TIMEOUT
+# Docker service timeouts
+DOCKER_CONTAINER_START_TIMEOUT = 40   # Timeout for individual container startup
+DOCKER_SERVICE_STARTUP_TIMEOUT = 180  # Timeout for full service startup
+DOCKER_PS_CHECK_TIMEOUT = 10  # Timeout for docker-compose ps command
+DOCKER_PULL_TIMEOUT = 30      # < DOCKER_SERVICE_STARTUP_TIMEOUT
 
 # General Docker operations timeout
 DOCKER_OPERATIONS_TIMEOUT = 20  # < DOCKER_CONTAINER_START_TIMEOUT
 
-# Service stabilization delay after startup
-SERVICE_STABILIZATION_DELAY = 15
-
-# Retry pause delay between attempts 
-RETRY_PAUSE_DELAY = 2
-
 # PostgreSQL connection check timeout
 POSTGRES_CONNECTION_TIMEOUT = 5  # < DOCKER_INFO_TIMEOUT
 
 # Docker info command timeout
 DOCKER_INFO_TIMEOUT = 5  # >= POSTGRES_CONNECTION_TIMEOUT
 
-# Docker pull operation timeout
-DOCKER_PULL_TIMEOUT = 30  # < DOCKER_SERVICE_STARTUP_TIMEOUT
-
 # Docker run operation timeout
 DOCKER_RUN_TIMEOUT = 10  # < DOCKER_CONTAINER_START_TIMEOUT
\ No newline at end of file
